DiagnosticAnalyticEvent class base
Generic analytic param.
This params contains the common diagnostic sdk analytic. If custom implementation is needed you always can extend and required your custom exception in sendAnalyticEvent function
Constructors
-
DiagnosticAnalyticEvent({required String name, required Map<
String, String> ? parameters}) -
const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- name → String
-
final
-
parameters
→ Map<
String, String> ? -
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited