DiagnosticLevel enum

Define the level event

Inheritance
Available extensions

Values

debug → const DiagnosticLevel

Usually Develop information

info → const DiagnosticLevel

Usually Tracking information

warning → const DiagnosticLevel

Usually Failure information

error → const DiagnosticLevel

Usually Uncontrol information

fatal → const DiagnosticLevel

Usually Fatal information

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
resolve<T>({required T onDebug, required T onInfo, required T onWarning, required T onError, required T onFatal}) → T
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<DiagnosticLevel>
A constant List of the values in this enum, in order of their declaration.