DiagnosticManager<T extends Diagnostic> class
base
Manage all the Diagnostic SDK on the project. Choose where is the better sdk for each function and filter if it is neccesary.
Generic can be provide for change the type of Diagnostic use in the project
- Implemented types
Constructors
-
DiagnosticManager({required List<
T> diagnostics, required DiagnosticManagerOption options}) -
const
Properties
-
diagnostic
→ List<
T> -
Diagnostic must be use only in the extension of the manager and not outside the package.
no setter
- hashCode → int
-
The hash code for this object.
no setterinherited
- options → DiagnosticManagerOption
-
Provide the multiple options for manage the diferent diagnostics sdk.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
captureException(
{required covariant DiagnosticExpection exception}) → FutureOr< void> -
Send an exception with the custom informate implement to all the diagnostic.
override
-
dispose(
) → Future< void> -
This function must be call before the instance is created an usually have close streams or dispose clients.
override
-
init(
) → Future< void> -
This function must be call at the begining of the initilalization.
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
sendAnalyticEvent(
{required covariant DiagnosticAnalyticEvent event}) → FutureOr< void> -
Send an analytic with the custom informate implement to all the diagnostic.
override
-
sendLogEvent(
{required covariant DiagnosticLogsEvent event}) → FutureOr< void> -
Send an log with the custom informate implement to all the diagnostic.
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited